
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( . ) );
__DATA__
Blowfish
CBC
Crypt
CryptX
DES
Dunkle
HMACSHA
Legge
Lincoln
OpenSSL
PBKDF
Stein
aes
blocksize
cbc
cipherblock
cryptographic
decrypt
decrypted
depadding
des
hasher
headerless
iter
keysize
lib
lstein
nodeprecate
none
ofb
oneandzeroes
opensslv1
opensslv2
paddings
pbkdf
pbkdf2
pcbc
plaintext
randomiv
